##  Step 2: Update the Data in the Spreadsheet
In the spreadsheet, each row corresponds to a fact sheet, and each column corresponds to a fact sheet attribute. The first row of each column contains the technical key of the attribute, and the second row contains its translation. It is important to use the correct technical keys and their translations in these rows for successfully mapping input data to the inventory.
**Tip**
Technical keys and translations for fact sheet attributes can be found in the fact sheet configuration. For more information, see [Attribute Key](https://help.sap.com/docs/leanix/ea/meta-model-configuration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275955467a441014a5dce078bf2e383c__attribute_key) and [Translations](https://help.sap.com/docs/leanix/ea/meta-model-configuration?locale=en-US&state=PRODUCTION&version=CLOUD#loio275955467a441014a5dce078bf2e383c__translations).
![Technical Keys and Translations of Fact Sheet Attributes in the Top Rows](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275083697a441014b29fede22b4fa147_LowRes.png)
Technical Keys and Translations of Fact Sheet Attributes in the Top Rows
Though the fact sheet ID is the only field used to identify a fact sheet, fact sheet type and name are a requirement for a successful import. Hence, these 3 columns are mandatory columns in the spreadsheet.
Complete or update the rest of the spreadsheet according to the formatting rules and the dependencies and overwrite principles detailed in the [Key Concepts and Formatting Rules](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a86917a441014872eecad909f5e9e__key_concepts_and_formatting_rules). Make sure you are familiar with these guidelines before making any updates.
Updating the cells can have the following outcomes when the file is imported:
  * Update existing fact sheet values: If you update existing values in the spreadsheet, the corresponding fact sheet attributes will be updated.
  * Delete fact sheet values: If you remove values from the cells, the corresponding values will be deleted from the fact sheet.
  * Populate empty attributes of fact sheets: Filling in empty cells in the spreadsheet will populate the empty fact sheet fields.
  * Create new fact sheets: If the fact sheet ID column is empty but the fact sheet type and name columns are completed, new fact sheets will be created. While filling the fact sheet type column, make sure that the exact technical key of the fact sheet type is used. Additionally, of course, you can include and fill any other columns as needed.
  * Archive fact sheets: To archive fact sheets, add a column with action as the technical key in the first row and Action as the translation in the second row. Fill the column with the value Archive against the fact sheets that need to be archived and import the spreadsheet. For detailed instructions, see [Archiving Fact Sheets in Bulk](https://help.sap.com/docs/leanix/ea/archiving-deleting-and-recovering-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758bfdf7a4410148e40d4c9a8ea607a__archiving_fact_sheets_in_bulk).
